# Conventions for PostgreSQL Global Development Group RPM releases:

# Official PostgreSQL Development Group RPMS have a PGDG after the release number.
# Integer releases are stable -- 0.1.x releases are Pre-releases, and x.y are
# test releases.

# Pre-releases are those that are built from CVS snapshots or pre-release
# tarballs from postgresql.org.  Official beta releases are not 
# considered pre-releases, nor are release candidates, as their beta or
# release candidate status is reflected in the version of the tarball. Pre-
# releases' versions do not change -- the pre-release tarball of 7.0.3, for
# example, has the same tarball version as the final official release of 7.0.3:
# but the tarball is different.

# Test releases are where PostgreSQL itself is not in beta, but certain parts of
# the RPM packaging (such as the spec file, the initscript, etc) are in beta.

# Pre-release RPM's should not be put up on the public ftp.postgresql.org server
# -- only test releases or full releases should be.
# This is the PostgreSQL Global Development Group Official RPMset spec file,
# or a derivative thereof.
# Copyright 2003 Lamar Owen <lowen@pari.edu> <lamar.owen@wgcr.org>
# and others listed.

# Major Contributors:
# ---------------
# Lamar Owen
# Trond Eivind Glomsrd <teg@redhat.com>
# Thomas Lockhart
# Reinhard Max
# Karl DeBisschop
# Peter Eisentraut
# Joe Conway
# Andrew Overholt
# David Jee
# Kaj J. Niemi
# Sander Steffann
# Tom Lane
# and others in the Changelog....

# This spec file and ancilliary files are licensed in accordance with 
# The PostgreSQL license.

# In this file you can find the default build package list macros.  These can be overridden by defining
# on the rpm command line:
# rpm --define 'packagename 1' .... to force the package to build.
# rpm --define 'packagename 0' .... to force the package NOT to build.
# The base package, the lib package, the devel package, and the server package always get built.

#build7x, build8, and build9 similar
%{?build7x:%define aconfver autoconf-2.53}
%{?build8:%define build89 1}
%{?build9:%define build89 1}

%define beta 0
%{?beta:%define __os_install_post /usr/lib/rpm/brp-compress}

%{!?aconfver:%define aconfver autoconf}

%{!?test:%define test 1}
%{!?ssl:%define ssl 1}
%{!?kerberos:%define kerberos 1}
%{!?nls:%define nls 1}
%{!?pam:%define pam 1}
%{!?pgfts:%define pgfts 1}
%{!?runselftest:%define runselftest 1}


Summary: Backlevel PostgreSQL client libraries.
Name: postgresqlclient81
Version: 8.1.17
Release: 1%{?dist}
License: BSD
Group: Applications/Databases
Url: http://www.postgresql.org/ 

Source0: ftp://ftp.postgresql.org/pub/source/v%{version}/postgresql-%{version}.tar.bz2

Patch1: rpm-pgsql.patch
Patch2: postgresql-8.1-libpqdomain.patch
Patch3: postgresql-ac-version.patch

Buildrequires: perl glibc-devel bison flex autoconf
Prereq: /sbin/ldconfig

BuildPrereq: readline-devel
BuildPrereq: zlib-devel >= 1.0.4

%if %ssl
BuildPrereq: openssl-devel
%endif

%if %kerberos
BuildPrereq: krb5-devel
BuildPrereq: e2fsprogs-devel
%endif

%if %nls
BuildPrereq: gettext >= 0.10.35
%endif

%if %pam
BuildPrereq: pam-devel
%endif

Buildroot: %{_tmppath}/%{name}-%{version}-%{release}-root

%description
This package contains backlevel versions of the PostgreSQL client libraries
for use with applications linked against them.  These shared libraries
were created using PostgreSQL 8.1.

Provides: libpq.so
Obsoletes: rh-postgresql-libs

%prep
%setup -q -n postgresql-%{version}
pushd doc
tar zxf postgres.tar.gz
popd
%patch1 -p1
%patch2 -p1
%patch3 -p1

#call autoconf 2.53 or greater
%aconfver

pushd doc
tar -zcf postgres.tar.gz *.html stylesheet.css
rm -f *.html stylesheet.css
popd

%build

CFLAGS="${CFLAGS:-%optflags}" ; export CFLAGS
CXXFLAGS="${CXXFLAGS:-%optflags}" ; export CXXFLAGS

# Strip out -ffast-math from CFLAGS....
CFLAGS=`echo $CFLAGS|xargs -n 1|grep -v ffast-math|xargs -n 100`

%configure --disable-rpath \
%if %beta
	--enable-debug \
	--enable-cassert \
%endif
%if %ssl
	--with-openssl \
%endif
%if %pam
	--with-pam \
%endif
%if %kerberos
	--with-krb5 \
%endif
%if %nls
	--enable-nls \
%endif
%if %pgfts
	--enable-thread-safety \
%endif
	--sysconfdir=/etc/sysconfig/pgsql \
	--datadir=/usr/share/pgsql \
	--with-docdir=%{_docdir}

make %{?_smp_mflags} all

%if %runselftest
	pushd src/test/regress
	make all
	make MAX_CONNECTIONS=5 check
	make clean
	popd
%endif

%install
rm -rf $RPM_BUILD_ROOT

make DESTDIR=$RPM_BUILD_ROOT install

# Remove stuff we don't want to ship (pretty much everything except the
# client-side libraries).
rm -rf $RPM_BUILD_ROOT/usr/share/locale/*/LC_MESSAGES/pg_controldata.mo
rm -rf $RPM_BUILD_ROOT/usr/share/locale/*/LC_MESSAGES/pg_dump.mo
rm -rf $RPM_BUILD_ROOT/usr/share/locale/*/LC_MESSAGES/pg_resetxlog.mo
rm -rf $RPM_BUILD_ROOT/usr/share/locale/*/LC_MESSAGES/pgscripts.mo
rm -rf $RPM_BUILD_ROOT/usr/share/locale/*/LC_MESSAGES/postgres.mo
rm -rf $RPM_BUILD_ROOT/usr/share/locale/*/LC_MESSAGES/psql.mo
rm -rf $RPM_BUILD_ROOT/usr/share/locale/*/LC_MESSAGES/initdb.mo
rm -rf $RPM_BUILD_ROOT/usr/share/locale/*/LC_MESSAGES/pg_config.mo
rm -rf $RPM_BUILD_ROOT/usr/share/locale/*/LC_MESSAGES/pg_ctl.mo
rm -rf $RPM_BUILD_ROOT/usr/share/pgsql
rm -rf $RPM_BUILD_ROOT%{_docdir}/pgsql/html
rm -rf $RPM_BUILD_ROOT%{_bindir}
rm -rf $RPM_BUILD_ROOT%{_includedir}
rm -rf $RPM_BUILD_ROOT%{_libexecdir}
rm -rf $RPM_BUILD_ROOT%{_infodir}
rm -rf $RPM_BUILD_ROOT%{_mandir}
rm -rf $RPM_BUILD_ROOT%{_libdir}/*.a
rm -rf $RPM_BUILD_ROOT%{_libdir}/*.so
rm -rf $RPM_BUILD_ROOT%{_libdir}/pgsql

# At the moment, we don't ship the ecpg libraries either because they have
# the same major version in PG 8.2 (was this an error?)
rm -rf $RPM_BUILD_ROOT%{_libdir}/libecpg.so.*
rm -rf $RPM_BUILD_ROOT%{_libdir}/libpgtypes.so.*
rm -rf $RPM_BUILD_ROOT%{_libdir}/libecpg_compat.so.*

# Adjust libpq.mo files to be named libpq81.mo.
for d in $RPM_BUILD_ROOT/usr/share/locale/*/LC_MESSAGES
do
	if [ -f $d/libpq.mo ]
	then
		mv -f $d/libpq.mo $d/libpq81.mo
	fi
done

%find_lang libpq81

cat libpq81.lang > libpq81.lst

%post -p /sbin/ldconfig 
%postun -p /sbin/ldconfig 

%clean
rm -rf $RPM_BUILD_ROOT

# FILES section.

%files -f libpq81.lang
%defattr(-,root,root)
%doc COPYRIGHT README HISTORY doc/bug.template
%{_libdir}/libpq.so.*
#%{_libdir}/libecpg.so.*
#%{_libdir}/libpgtypes.so.*
#%{_libdir}/libecpg_compat.so.*

%changelog
* Tue Apr  7 2009 Tom Lane <tgl@redhat.com> 8.1.17-1
- Update to PostgreSQL 8.1.17

* Thu Oct 16 2008 Tom Lane <tgl@redhat.com> 8.1.14-1
- Update to PostgreSQL 8.1.14

* Tue Mar  4 2008 Tom Lane <tgl@redhat.com> 8.1.11-1
- Update to PostgreSQL 8.1.11

* Wed Apr 25 2007 Tom Lane <tgl@redhat.com> 8.1.9-1
- Update to PostgreSQL 8.1.9; build for Stacks V2

* Mon Dec 11 2006 Tom Lane <tgl@redhat.com> 8.1.5-1
- Created by stripping down current Fedora SRPM, using postgresqlclient7
  as a model.
